Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(417)

Unified Diff: ports/devenv/build.sh

Issue 1563073002: Re-enable io2014 + add cds2014 tests for devenv. (Closed) Base URL: https://chromium.googlesource.com/webports.git@master
Patch Set: fix Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ports/devenv-latest/build.sh ('k') | ports/devenv/demo2014_test.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ports/devenv/build.sh
diff --git a/ports/devenv/build.sh b/ports/devenv/build.sh
index c548396e348cae5c84186679fe201b6d68ffc13a..f5407af081a5bad4c7761ee2d6c4d3cb1045e76f 100644
--- a/ports/devenv/build.sh
+++ b/ports/devenv/build.sh
@@ -11,7 +11,7 @@ EXECUTABLES="tests/devenv_small_test_${NACL_ARCH}${NACL_EXEEXT} \
STORAGE_URL=https://webports.storage.googleapis.com/builds
SDK_VERSION=pepper_51
-BUILT_REVISION=trunk-834-gf476174
+BUILT_REVISION=trunk-837-gd9eb95d
DEFAULT_SOURCE=${STORAGE_URL}/${SDK_VERSION}/${BUILT_REVISION}/publish
LOCAL_SOURCE=http://localhost:5103
@@ -190,12 +190,12 @@ PostInstallTestStep() {
if [[ ${NACL_ARCH} == pnacl ]]; then
LogExecute python ${START_DIR}/jseval_test.py -x -v -a ${arch}
fi
# Run large and io2014 tests only on the buildbots (against pinned revs).
if [[ -n ${BUILDBOT_BUILDERNAME:-} ]]; then
LogExecute python ${START_DIR}/../devenv/devenv_large_test.py \
-x -v -a ${arch}
- #LogExecute python ${START_DIR}/../devenv/io2014_test.py \
- #-x -v -a ${arch}
+ LogExecute python ${START_DIR}/../devenv/demo2014_test.py \
+ -x -v -a ${arch}
fi
done
}
@@ -190,12 +190,12 @@ PostInstallTestStep() {
LogExecute python ${START_DIR}/jseval_test.py -x -v -a ${arch}
fi
- # Run large and io2014 tests only on the buildbots (against pinned revs).
+ # Run large and demo2014 tests only on the buildbots (against pinned revs).
if [[ -n ${BUILDBOT_BUILDERNAME:-} ]]; then
LogExecute python ${START_DIR}/../devenv/devenv_large_test.py \
« no previous file with comments | « ports/devenv-latest/build.sh ('k') | ports/devenv/demo2014_test.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698